KeyCode

Enum KeyCode 

pub enum KeyCode {
Show 18 variants Char(char), F(u8), Backspace, Enter, Left, Right, Up, Down, Home, End, PageUp, PageDown, Tab, BackTab, Delete, Insert, Esc, Null,
}
Key code representation.

Represents the physical/logical key pressed.

Variants



Char(char)

Regular character



F(u8)

Function key (F1-F12)



Backspace

Backspace



Enter

Enter/Return



Left

Left arrow



Right

Right arrow



Up

Up arrow



Down

Down arrow



Home

Home



End

End



PageUp

Page Up



PageDown

Page Down



Tab

Tab



BackTab

Backab (Shift+Tab)



Delete

Delete



Insert

Insert



Esc

Escape



Null

Null (Ctrl+Space on some terminals)

Implementations

Source

impl KeyCode

pub const fn is_char(&self) -> bool

Check if this is a character key.

pub const fn as_char(&self) -> Option<char>

Get the character if this is a character key.