BufferClosed

Struct BufferClosed 

pub struct BufferClosed {
    pub buffer_id: u64,
}
A buffer was closed/destroyed.

Emitted when a buffer is deallocated from the kernel. Handlers should clean up any state associated with this buffer.

Fields

buffer_id: u64

ID of the closed buffer