BufferWillSave

Struct BufferWillSave 

pub struct BufferWillSave {
    pub buffer_id: u64,
    pub path: String,
}
A buffer is about to be saved to disk.

Emitted before buffer content is persisted. Subscribers can modify the buffer content (e.g., format-on-save) and the write command will pick up the formatted content. Dispatch is synchronous.

Fields

buffer_id: u64

ID of the buffer about to be saved

path: String

Path the buffer will be saved to