ModuleContext

Struct ModuleContext 

pub struct ModuleContext {
    pub kernel: KernelContext,
    pub services: Arc<ServiceRegistry>,
    pub data_dir: PathBuf,
    pub cache_dir: PathBuf,
    /* private fields */
}
Context provided to modules during initialization.

Extends KernelContext with module-specific paths for data and cache storage, plus access to the cross-module service registry. This is passed to Module::init() and provides everything a module needs to initialize itself.

Example

use reovim_kernel::api::v1::{Module, ModuleContext, ProbeResult};

impl Module for MyModule {
    fn init(&mut self, ctx: &ModuleContext) -> ProbeResult {
        // Access kernel services
        let bus = &ctx.kernel.event_bus;

        // Access module-specific directories
        let config_path = ctx.data_dir.join("config.toml");
        let cache_path = ctx.cache_dir.join("cache.bin");

        // Register services for other modules to discover
        ctx.services.register(Arc::new(MyService::new()));

        ProbeResult::Success
    }
}

Fields

kernel: KernelContext

Kernel context for core services.

services: Arc<ServiceRegistry>

Service registry for cross-module service discovery.

Modules can register their services here during init() for other modules to discover. See ServiceRegistry for usage patterns.

data_dir: PathBuf

Module’s data directory (persistent storage).

e.g., ~/.local/share/reovim/modules/<module-id>/

cache_dir: PathBuf

Module’s cache directory (ephemeral storage).

e.g., ~/.cache/reovim/modules/<module-id>/

Implementations

Source

impl ModuleContext

pub fn new( kernel: KernelContext, services: Arc<ServiceRegistry>, data_dir: PathBuf, cache_dir: PathBuf, ) -> Self

Create a new module context.

pub fn with_optional_deps( kernel: KernelContext, services: Arc<ServiceRegistry>, data_dir: PathBuf, cache_dir: PathBuf, loaded_optional_deps: Vec<ModuleId>, ) -> Self

Create a module context with optional dependencies info.

pub fn has_optional_dep(&self, id: &ModuleId) -> bool

Check if an optional dependency was loaded.

Example
use reovim_kernel::api::v1::{ModuleContext, ModuleId};

fn init(ctx: &ModuleContext) {
    if ctx.has_optional_dep(&ModuleId::new("lsp")) {
        // Enable LSP integration
    }
}
pub fn optional_deps(&self) -> &[ModuleId]

Get all loaded optional dependencies.

Returns a slice of ModuleIds for optional dependencies that were successfully loaded before this module’s initialization.

Example
use reovim_kernel::api::v1::ModuleContext;

fn init(ctx: &ModuleContext) {
    for dep in ctx.optional_deps() {
        println!("Optional dep available: {}", dep.as_str());
    }
}