pub struct SetLoggerError;Expand description
Error returned when attempting to set the logger more than once.
The global logger can only be set once. This error is returned
if set_logger() is called after a logger has already been set.