pub struct TabId(/* private fields */);Expand description
Unique tab page identifier.
Tab pages are identified by a unique, monotonically increasing ID. This is a lightweight handle that can be cheaply cloned and compared.
Example
use reovim_kernel::api::v1::TabId;
let tab1 = TabId::new();
let tab2 = TabId::new();
assert_ne!(tab1, tab2);
assert_eq!(tab1, tab1);Implementations