pub struct WindowId(/* private fields */);Expand description
Unique window identifier.
Windows are identified by a unique, monotonically increasing ID. This is a lightweight handle that can be cheaply cloned and compared.
Example
use reovim_kernel::api::v1::WindowId;
let window1 = WindowId::new();
let window2 = WindowId::new();
assert_ne!(window1, window2);
assert_eq!(window1, window1);Implementations