Service

Trait Service 

pub trait Service:
    Send
    + Sync
    + 'static { }
Marker trait for services that can be registered in ServiceRegistry.

Implement this trait for types that should be discoverable via the service registry. The trait bounds ensure thread-safety.

Implementors

Source

impl<K: ServiceKey, T: ?Sized + Send + Sync + 'static> Service for MultiServiceRegistry<K, T>