pub fn setup_buffer(ctx: &KernelContext, content: &str) -> BufferIdExpand description
Create a buffer with content and register it in the context.
Convenience helper that combines Buffer::from_string() and
ctx.buffers.register().
pub fn setup_buffer(ctx: &KernelContext, content: &str) -> BufferIdCreate a buffer with content and register it in the context.
Convenience helper that combines Buffer::from_string() and
ctx.buffers.register().