CommandId

Struct CommandId 

pub struct CommandId { /* private fields */ }
Namespaced command identifier.

Commands are identified by their owning module and a local name. This prevents naming conflicts between modules.

Example

use reovim_kernel::api::v1::{CommandId, ModuleId};

let editor_module = ModuleId::new("editor");
let cursor_down = CommandId::new(editor_module.clone(), "cursor-down");
let cursor_up = CommandId::new(editor_module, "cursor-up");

assert_eq!(cursor_down.name(), "cursor-down");
assert_ne!(cursor_down, cursor_up);

Implementations

Source

impl CommandId

pub const fn new(module: ModuleId, name: &'static str) -> Self

Create a new command identifier.

pub fn from_qualified_leaked(qualified: String) -> Self

Create a command identifier from a qualified string like “module:command”.

This method is intended for dynamic use cases like FFI where command IDs are specified as strings at runtime. The strings are leaked to get 'static lifetime, so this should only be used for long-lived commands.

If the string doesn’t contain ‘:’, the entire string is treated as the command name with “unknown” as the module.

Example
use reovim_kernel::api::v1::CommandId;

let cmd = CommandId::from_qualified_leaked("editor:cursor-down".to_string());
assert_eq!(cmd.module().as_str(), "editor");
assert_eq!(cmd.name(), "cursor-down");
pub const fn module(&self) -> &ModuleId

Get the owning module.

pub const fn name(&self) -> &'static str

Get the local name.